Enums
Statics
Traits
- Context
- Provides the
wrap_errmethod forResult. - Section
- A helper trait for attaching informational sections to error reports to be displayed after the chain of errors
Functions
Type Aliases
- Result
- type alias for
Result<T, Report>